@@ -303,7 +303,7 @@ countVarChunkMissingVals(int vlistID, int varID,
                          struct streamMapping *mapping,
                          int chunkLen, const double *restrict data)
 {
-  int nmiss = 0;
+  size_t nmiss = 0;
   if (mapping->hasMissing[varID])
     {
       double missval = vlistInqVarMissval(vlistID, varID);
@@ -450,7 +450,7 @@ writeNetCDFStream(size_t streamIdx,
           xt_idxlist_delete(preWriteChunk);
         }
         /* count missing values if appropriate */
-        int nmiss
+        size_t nmiss
           = countVarChunkMissingVals(vlistID, varID, mapping,
                                      PPM_extents_size(3, varChunk),
                                      data);
@@ -553,7 +553,7 @@ writeNetCDFStream(size_t streamIdx,
         gatherArray(headerIdx, streamIdx, data, dstList, conf);
         if (writerRank == collRank)
           {
-            int nmiss = countVarChunkMissingVals(vlistID, varID,
+            size_t nmiss = countVarChunkMissingVals(vlistID, varID,
                                                  mapping, varSize, data);
             streamWriteVar(streamID, varID, data, nmiss);
           }
@@ -1053,7 +1053,7 @@ writeGribStream(size_t streamIdx,
             varIdx += varID != prevVarID;
             size_t recordSize = writtenRecords[recordIdx].dataSize;
             size_t nvals = recordSize / sizeof (double);
-            int nmiss
+            size_t nmiss
               = countVarChunkMissingVals(vlistID, varID, mapping, (int)nvals,
                                          data + recordDataOfs);
             streamWriteVarSlice(streamID, varID, level, data + recordDataOfs, nmiss);
@@ -1109,14 +1109,16 @@ readGetBuffers(size_t streamIdx, const struct cdiPioConf *conf)
 
     switch (filetype)
       {
-      case FILETYPE_GRB:
-      case FILETYPE_GRB2:
+      case CDI_FILETYPE_GRB:
+      case CDI_FILETYPE_GRB2:
         writeGribStream(streamIdx, map, &data, &currentDataBufSize, conf);
         break;
 #ifdef HAVE_NETCDF4
-      case FILETYPE_NC:
-      case FILETYPE_NC2:
-      case FILETYPE_NC4:
+      case CDI_FILETYPE_NC:
+      case CDI_FILETYPE_NC2:
+      case CDI_FILETYPE_NC4:
+      case CDI_FILETYPE_NC4C:
+      case CDI_FILETYPE_NC5:
         writeNetCDFStream(streamIdx, map, &data, &currentDataBufSize, conf);
         break;
 #endif
@@ -1193,8 +1195,8 @@ cdiPioServerStreamOpen(const char *filename, char filemode,
   switch (filetype)
     {
 #if defined HAVE_LIBNETCDF && ! defined HAVE_PARALLEL_NC4
-    case FILETYPE_NC4:
-    case FILETYPE_NC4C:
+    case CDI_FILETYPE_NC4:
+    case CDI_FILETYPE_NC4C:
       {
         int ioMode = commInqIOMode();
         if (ioMode == PIO_NONE
@@ -1258,10 +1260,11 @@ cdiPioServerStreamClose(stream_t *streamptr, int recordBufIsToBeDeleted)
       switch (filetype)
         {
 #if defined (HAVE_LIBNETCDF) && ! defined (HAVE_PARALLEL_NC4)
-        case FILETYPE_NC:
-        case FILETYPE_NC2:
-        case FILETYPE_NC4:
-        case FILETYPE_NC4C:
+        case CDI_FILETYPE_NC:
+        case CDI_FILETYPE_NC2:
+        case CDI_FILETYPE_NC4:
+        case CDI_FILETYPE_NC4C:
+        case CDI_FILETYPE_NC5:
           {
             int rank, rankOpen = cdiPioSerialOpenFileMap(streamptr->self);
             if (commInqIOMode() == PIO_NONE
